<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>版本 %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 是自由软件，但它的开发需要宝贵的时间。</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>请 &lt;a href=&apos;%1&apos;&gt;捐助&lt;/a&gt; 来支持 %2 的开发。</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>依据 &lt;a href=&apos;%1&apos;&gt;GNU 通用公共许可证&lt;/a&gt; 分发</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(_B)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>那些关于 %1 您总想知道却又不敢问的事情</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>您或许也想尝试我的其他程序：</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1，一个 YouTube 程序</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1，一个 YouTube 音乐播放器</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>使用 %2 将 %1 翻译为您的母语</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>遵循协议：%1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>输入您的许可详情</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>邮件(_E)：</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>激活码(_C)：</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>请购买 %1 授权</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>该试用版已经过期。</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>若无许可证，该软件将会在 %1 天后过期。</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>购买完整版本的同时，您也能支持我在创建 %1 时付出的努力。</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>使用试用版</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>输入许可</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>购买许可</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>完整版本允许您将超过 %1 首曲目添加到播放列表中且聆听音乐时不会受到打扰。</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>在 %1 购买</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>阅读更多</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>艺术家</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>年代</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>流行度</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>逆序</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>排序</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>阅读更多</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>曲目统计</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>专辑统计</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>姓名</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>年代</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>流行度</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>逆序</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>排序</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>后退(_B)</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>向后退</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>欢迎使用&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;！</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 需要扫描您的音乐收藏。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>使用 iTunes 收藏</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>使用 %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>选择一个文件夹……</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 将连结至 Last.fm 网络服务器并提交艺术家名称和唱片标题来获取封面、艺人介绍及更多内容。</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>如果您对此有隐私上的顾虑您可以现在退出。</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>您的音乐收藏在哪里？</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>选择您音乐收藏的位置。</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>定位您的收藏</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>一个扫描任务已在进行中</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 正在扫描您的音乐收藏。</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 正在用 &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; 归类您的音乐。</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>这会占用一定时间，时间长短取决于您的音乐库大小和网络速度。</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>去喝杯咖啡吧</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>正在下载更新...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>拖放到这里来添加到播放列表</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>艺术家</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>专辑</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>文件夹</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>播放/暂停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>播放完当前音轨后停止</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>下一首</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>上一首</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>增大音量</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>降低音量</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>向前搜索</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>向后搜索</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>认证失败</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>登录至 %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>用户名(_U)：</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>密码(_P)：</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>注册一个 %1 帐号</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>忘记您的&lt;a href=&apos;%1&apos;&gt;用户名&lt;/a&gt; 或 &lt;a href=&apos;%2&apos;&gt;密码&lt;/a&gt;？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>后退(_B)</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>前往上一个视图</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>信息(_I)</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>显示当前音轨信息</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>上一首(_R)</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>回退到上一首音轨</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>下一首(_N)</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>跳至下一首音轨</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>播放(_P)</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>开始回放</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>全屏(_F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>切换到全屏</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>删除(_R)</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>从播放列表删除选中音轨</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>向上移动(_U)</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>在播放列表中向上移动选定音轨</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>向下移动(_D)</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>在播放列表中向下移动选定音轨</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>退出(_Q)</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>拜拜</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>更改收藏文件夹…(_C)</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>另选一个音乐收藏文件夹</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>网站(_W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 在网上</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>发起捐助(_D)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>请支持 %1 的持续开发</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>关于(_A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>关于 %1 的信息</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>清空(_C)</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>删除播放列表中的所有音轨</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>随机(_S)</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>随机播放列表模式</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>重复(_R)</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>所有歌曲播放结束后返回播放第一首</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>应用程序(_A)</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>回放(_P)</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>播放列表(_L)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>查看(_V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(_H)</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>点击 %1 来提高音量，%2 降低音量</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>正在打开 %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>正在更新收藏…</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>正在更新收藏 - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>收藏更新完毕</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>严重错误：%1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>错误：%1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>离开全屏模式(_F)</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>剩余时间：%1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>音量 %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>已静音</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>已取消静音</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>获得完整版本</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 版本 %2 现在可用。</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>稍后提醒我</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>窗口(_W)</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>最小化(_M)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>购买 %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>播放此音轨后停止(_S)</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>同步(_S)</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>发送已播放音轨标题至 %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>从 %1 登出(_L)</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>报告问题…(_R)</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 扫描乐收藏完毕</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>喜欢 %1? 为其评分！</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>拖放条目到这里</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>播放列表完成</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>这只是 %1 的试用版本。</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>它允许您播放一些音轨，以便您测试并了解该程序是否适合您。</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>获得完整版本</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>发现新版本的 %1 ！</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 已经可用。您现拥有 %3。</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>您想现在下载吗？</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>跳过此版本</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>稍后提醒我</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>安装更新</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>该试用版只能在播放列表中添加 %1 首音轨。</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>播放列表为空</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 音轨数 - 总长度为 %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>您的搜索无结果。</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>音轨</translation>
    </message>
</context>
</TS>